@@ -38,6 +38,7 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.Constructor_Detail", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u306E\u8A73\u7D30" },
             { "doclet.Constructor_Summary", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF\u306E\u6982\u8981" },
             { "doclet.Constructors", "\u30B3\u30F3\u30B9\u30C8\u30E9\u30AF\u30BF" },
+            { "doclet.Copy_Ignored_warning", "\u30D5\u30A1\u30A4\u30EB{0}\u306F\u30B3\u30D4\u30FC\u3055\u308C\u307E\u305B\u3093\u3067\u3057\u305F: \u540D\u524D\u304C\u7121\u52B9\u3067\u3059" },
             { "doclet.Copy_Overwrite_warning", "\u30D5\u30A1\u30A4\u30EB{0}\u306F\u540C\u3058\u540D\u524D\u306E\u30D5\u30A1\u30A4\u30EB\u304C\u3042\u308B\u306E\u3067{1}\u306B\u30B3\u30D4\u30FC\u3055\u308C\u307E\u305B\u3093\u3067\u3057\u305F..." },
             { "doclet.Copying_File_0_To_Dir_1", "\u30D5\u30A1\u30A4\u30EB{0}\u3092\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA{1}\u306B\u30B3\u30D4\u30FC\u4E2D..." },
             { "doclet.Copying_File_0_To_File_1", "\u30D5\u30A1\u30A4\u30EB{0}\u3092\u30D5\u30A1\u30A4\u30EB{1}\u306B\u30B3\u30D4\u30FC\u4E2D..." },
@@ -56,12 +57,10 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.Enum_Constants", "\u5217\u6319\u5B9A\u6570" },
             { "doclet.Enum_Summary", "\u5217\u6319\u578B\u306E\u6982\u8981" },
             { "doclet.Enums", "\u5217\u6319" },
-            { "doclet.Error", "\u30A8\u30E9\u30FC" },
             { "doclet.Error_Summary", "\u30A8\u30E9\u30FC\u306E\u6982\u8981" },
             { "doclet.Error_invalid_custom_tag_argument", "\u30A8\u30E9\u30FC - {0}\u306F-tag\u30AA\u30D7\u30B7\u30E7\u30F3\u306B\u5BFE\u3057\u3066\u7121\u52B9\u306A\u5F15\u6570\u3067\u3059..." },
             { "doclet.Error_taglet_not_registered", "\u30A8\u30E9\u30FC - \u30BF\u30B0\u30EC\u30C3\u30C8{1}\u3092\u767B\u9332\u3057\u3088\u3046\u3068\u3057\u3066\u3044\u308B\u3068\u304D\u306B\u3001\u4F8B\u5916{0}\u304C\u30B9\u30ED\u30FC\u3055\u308C\u307E\u3057\u305F..." },
             { "doclet.Errors", "\u30A8\u30E9\u30FC" },
-            { "doclet.Exception", "\u4F8B\u5916" },
             { "doclet.Exception_Summary", "\u4F8B\u5916\u306E\u6982\u8981" },
             { "doclet.Exceptions", "\u4F8B\u5916" },
             { "doclet.ExportedTo", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8" },
@@ -110,10 +109,10 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.Nested_Classes_Interfaces_Inherited_From_Class", "\u30AF\u30E9\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9/\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
             { "doclet.Nested_Classes_Interfaces_Inherited_From_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30CD\u30B9\u30C8\u3055\u308C\u305F\u30AF\u30E9\u30B9/\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
             { "doclet.No_Public_Classes_To_Document", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308Bpublic\u307E\u305F\u306Fprotected\u30AF\u30E9\u30B9\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3002" },
-            { "doclet.Notice_taglet_conflict_warn", "\u6CE8\u610F: \u6A19\u6E96\u30BF\u30B0\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B\u53EF\u80FD\u6027\u306E\u3042\u308B\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}\u3002\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3092\u907F\u3051\u308B\u305F\u3081\u306B\u3001\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0\u540D\u306E\u4E2D\u306B\u5C11\u306A\u304F\u3068\u30821\u3064\u306E\u30D4\u30EA\u30AA\u30C9(.)\u3092\u4F7F\u7528\u3057\u3066\u304F\u3060\u3055\u3044\u3002" },
-            { "doclet.Notice_taglet_overriden", "\u6CE8\u610F: \u6A19\u6E96\u30BF\u30B0\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}" },
+            { "doclet.Notice_taglet_conflict_warn", "\u30CE\u30FC\u30C8: \u6A19\u6E96\u30BF\u30B0\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B\u53EF\u80FD\u6027\u306E\u3042\u308B\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}\u3002\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3092\u907F\u3051\u308B\u305F\u3081\u306B\u3001\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0\u540D\u306E\u4E2D\u306B\u5C11\u306A\u304F\u3068\u30821\u3064\u306E\u30D4\u30EA\u30AA\u30C9(.)\u3092\u4F7F\u7528\u3057\u3066\u304F\u3060\u3055\u3044\u3002" },
+            { "doclet.Notice_taglet_overridden", "\u30CE\u30FC\u30C8: \u6A19\u6E96\u30BF\u30B0\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}" },
             { "doclet.Notice_taglet_registered", "\u767B\u9332\u3055\u308C\u305F\u30BF\u30B0\u30EC\u30C3\u30C8{0} ..." },
-            { "doclet.Notice_taglet_unseen", "\u6CE8\u610F: \u975E\u8868\u793A\u306E\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}" },
+            { "doclet.Notice_taglet_unseen", "\u30CE\u30FC\u30C8: \u975E\u8868\u793A\u306E\u30AB\u30B9\u30BF\u30E0\u30FB\u30BF\u30B0: {0}" },
             { "doclet.OpenedTo", "\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u30AA\u30FC\u30D7\u30F3" },
             { "doclet.Opened_Packages_Summary", "\u30AA\u30FC\u30D7\u30F3" },
             { "doclet.Option_conflict", "\u30AA\u30D7\u30B7\u30E7\u30F3{0}\u304C{1}\u3068\u77DB\u76FE\u3057\u307E\u3059" },
@@ -137,9 +136,7 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.Properties_Inherited_From_Interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u304B\u3089\u7D99\u627F\u3055\u308C\u305F\u30D7\u30ED\u30D1\u30C6\u30A3" },
             { "doclet.Property", "\u30D7\u30ED\u30D1\u30C6\u30A3" },
             { "doclet.PropertyDescription", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u8AAC\u660E:" },
-            { "doclet.PropertyGetter", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u5024\u3092\u53D6\u5F97\u3057\u307E\u3059" },
             { "doclet.PropertyGetterWithName", "\u30D7\u30ED\u30D1\u30C6\u30A3{0}\u306E\u5024\u3092\u53D6\u5F97\u3057\u307E\u3059\u3002" },
-            { "doclet.PropertySetter", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u5024\u3092\u8A2D\u5B9A\u3057\u307E\u3059" },
             { "doclet.PropertySetterWithName", "\u30D7\u30ED\u30D1\u30C6\u30A3{0}\u306E\u5024\u3092\u8A2D\u5B9A\u3057\u307E\u3059\u3002" },
             { "doclet.Property_Detail", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u8A73\u7D30" },
             { "doclet.Property_Summary", "\u30D7\u30ED\u30D1\u30C6\u30A3\u306E\u6982\u8981" },
@@ -152,7 +149,7 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.Requires_Summary", "\u5FC5\u8981" },
             { "doclet.Return_tag_on_void_method", "\u623B\u308A\u5024\u306E\u578B\u304Cvoid\u306E\u30E1\u30BD\u30C3\u30C9\u3067\u306F@return\u30BF\u30B0\u3092\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002" },
             { "doclet.Returns", "\u623B\u308A\u5024:" },
-            { "doclet.See", "\u53C2\u7167\u5148:" },
+            { "doclet.Returns_0", "{0}\u3092\u8FD4\u3057\u307E\u3059\u3002" },
             { "doclet.See_Also", "\u95A2\u9023\u9805\u76EE:" },
             { "doclet.SerialData", "\u30B7\u30EA\u30A2\u30EB\u30FB\u30C7\u30FC\u30BF:" },
             { "doclet.Serializable_no_customization", "readObject\u307E\u305F\u306FwriteObject\u30E1\u30BD\u30C3\u30C9\u304C\u5BA3\u8A00\u3055\u308C\u3066\u3044\u307E\u305B\u3093\u3002" },
@@ -193,14 +190,10 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.enum_values_doc.fullbody", "\u3053\u306E\u5217\u6319\u578B\u306E\u5B9A\u6570\u3092\u542B\u3080\u914D\u5217\u3092\u5BA3\u8A00\u3055\u308C\u3066\u3044\u308B\u9806\u5E8F\u3067\n\u8FD4\u3057\u307E\u3059\u3002" },
             { "doclet.enum_values_doc.return", "\u3053\u306E\u5217\u6319\u578B\u306E\u5B9A\u6570\u3092\u542B\u3080\u3001\u5BA3\u8A00\u3055\u308C\u3066\u3044\u308B\u9806\u5E8F\u3067\u306E\u914D\u5217" },
             { "doclet.enums", "\u5217\u6319" },
-            { "doclet.error", "\u30A8\u30E9\u30FC" },
             { "doclet.error.initializing.dest.dir", "\u8EE2\u9001\u5148\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u306E\u521D\u671F\u5316\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}" },
-            { "doclet.errors", "\u30A8\u30E9\u30FC" },
-            { "doclet.exception", "\u4F8B\u5916" },
             { "doclet.exception.read.file", "\u30D5\u30A1\u30A4\u30EB\u306E\u8AAD\u53D6\u308A\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}\n\t({1})" },
             { "doclet.exception.read.resource", "\u30B7\u30B9\u30C6\u30E0\u30FB\u30EA\u30BD\u30FC\u30B9\u306E\u8AAD\u53D6\u308A\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}\n\t({1})" },
             { "doclet.exception.write.file", "\u30D5\u30A1\u30A4\u30EB\u306E\u66F8\u8FBC\u307F\u4E2D\u306B\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}\n\t({1})" },
-            { "doclet.exceptions", "\u4F8B\u5916" },
             { "doclet.fields", "\u30D5\u30A3\u30FC\u30EB\u30C9" },
             { "doclet.in", "{1}\u306E{0}" },
             { "doclet.interface", "\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9" },
@@ -214,6 +207,10 @@ public final class doclets_ja extends java.util.ListResourceBundle {
             { "doclet.noInheritedDoc", "@inheritDoc\u304C\u4F7F\u7528\u3055\u308C\u3066\u3044\u307E\u3059\u304C\u3001{0}\u306F\u3069\u306E\u30E1\u30BD\u30C3\u30C9\u3082\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u307E\u305F\u306F\u5B9F\u88C5\u3057\u3066\u3044\u307E\u305B\u3093\u3002" },
             { "doclet.not_standard_file_manager", "\u30BF\u30FC\u30B2\u30C3\u30C8\u30FB\u30D1\u30B9\u3092\u8A2D\u5B9A\u3067\u304D\u307E\u305B\u3093\u3002\u30D5\u30A1\u30A4\u30EB\u30FB\u30DE\u30CD\u30FC\u30B8\u30E3\u304CStandardJavaFileManager\u3067\u306F\u3042\u308A\u307E\u305B\u3093" },
             { "doclet.packages", "\u30D1\u30C3\u30B1\u30FC\u30B8" },
+            { "doclet.platform.docs.ea", "https://download.java.net/java/early_access/jdk{0}/docs/api/" },
+            { "doclet.platform.docs.new", "https://docs.oracle.com/en/java/javase/{0}/docs/api/" },
+            { "doclet.platform.docs.old", "https://docs.oracle.com/javase/{0}/docs/api/" },
+            { "doclet.record", "\u30EC\u30B3\u30FC\u30C9" },
             { "doclet.record_accessor_doc.fullbody", "{0}\u30EC\u30B3\u30FC\u30C9\u30FB\u30B3\u30F3\u30DD\u30FC\u30CD\u30F3\u30C8\u306E\u5024\u304C\u8FD4\u3055\u308C\u307E\u3059\u3002" },
             { "doclet.record_accessor_doc.return", "{0}\u30EC\u30B3\u30FC\u30C9\u30FB\u30B3\u30F3\u30DD\u30FC\u30CD\u30F3\u30C8\u306E\u5024" },
             { "doclet.record_constructor_doc.fullbody", "{0}\u30EC\u30B3\u30FC\u30C9\u306E\u30A4\u30F3\u30B9\u30BF\u30F3\u30B9\u3092\u4F5C\u6210\u3057\u307E\u3059\u3002" },
